import React, { useState } from 'react';
import { Animated, TouchableOpacity, StyleSheet, Image } from 'react-native';
const AnimatedBounceButton = ({
  containerStyle,
  iconColors = '#0000ff',
  circleHeight = 60,
  circleWidth = 60,
  centralIcon,
  iconStyle,
  onPress,
  // Extracting onPress from props
  initialScale = 1,
  finalScale = 1.5,
  animationDuration = 500
}) => {
  const [animation] = useState(new Animated.Value(0));
  const handlePress = () => {
    onPress && onPress();
    Animated.spring(animation, {
      toValue: 1,
      useNativeDriver: true,
      speed: 8 / animationDuration // Adjust speed based on animation duration
    }).start(() => {
      Animated.spring(animation, {
        toValue: 0,
        useNativeDriver: true,
        speed: 8 / animationDuration // Adjust speed based on animation duration
      }).start();
    });
  };
  const animatedStyle = {
    transform: [{
      scale: animation.interpolate({
        inputRange: [0, 1],
        outputRange: [initialScale, finalScale] // Use initialScale and finalScale
      })
    }]
  };
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    onPress: handlePress,
    style: [styles.button, containerStyle]
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.circle, animatedStyle, {
      backgroundColor: iconColors,
      height: circleHeight,
      width: circleWidth
    }]
  }, /*#__PURE__*/React.createElement(Image, {
    source: centralIcon,
    style: [styles.icon, iconStyle]
  })));
};
const styles = StyleSheet.create({
  button: {
    position: 'absolute',
    bottom: 30,
    right: 30
  },
  circle: {
    borderRadius: 100,
    justifyContent: 'center',
    alignItems: 'center'
  },
  icon: {
    width: 30,
    height: 30
  }
});
export default AnimatedBounceButton;
//# sourceMappingURL=index.js.map